Class: ReportPrint::Printer::State

Inherits:
Data show all
Defined in:
lib/report_print/printer.rb

Overview

:nodoc:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Data

#report_print

Instance Attribute Details

#afterObject (readonly)

Returns the value of attribute after

Returns:

  • (Object)

    the current value of after



8
9
10
# File 'lib/report_print/printer.rb', line 8

def after
  @after
end

#indentObject (readonly)

Returns the value of attribute indent

Returns:

  • (Object)

    the current value of indent



8
9
10
# File 'lib/report_print/printer.rb', line 8

def indent
  @indent
end

#inline_separatorObject (readonly)

Returns the value of attribute inline_separator

Returns:

  • (Object)

    the current value of inline_separator



8
9
10
# File 'lib/report_print/printer.rb', line 8

def inline_separator
  @inline_separator
end

#modeObject (readonly)

Returns the value of attribute mode

Returns:

  • (Object)

    the current value of mode



8
9
10
# File 'lib/report_print/printer.rb', line 8

def mode
  @mode
end

#next_inline_separatorObject (readonly)

Returns the value of attribute next_inline_separator

Returns:

  • (Object)

    the current value of next_inline_separator



8
9
10
# File 'lib/report_print/printer.rb', line 8

def next_inline_separator
  @next_inline_separator
end

#separatorObject (readonly)

Returns the value of attribute separator

Returns:

  • (Object)

    the current value of separator



8
9
10
# File 'lib/report_print/printer.rb', line 8

def separator
  @separator
end

#start_of_blockObject (readonly)

Returns the value of attribute start_of_block

Returns:

  • (Object)

    the current value of start_of_block



8
9
10
# File 'lib/report_print/printer.rb', line 8

def start_of_block
  @start_of_block
end

#start_of_lineObject (readonly)

Returns the value of attribute start_of_line

Returns:

  • (Object)

    the current value of start_of_line



8
9
10
# File 'lib/report_print/printer.rb', line 8

def start_of_line
  @start_of_line
end

Instance Method Details

#inline?Boolean

Ruby type checking can't really handle this type of dynamic programming very well yet, so we just skip type checking here as there is only the one short function. steep:ignore:start

Returns:

  • (Boolean)


22
23
24
# File 'lib/report_print/printer.rb', line 22

def inline?
  mode == :inline
end