Class: ReportPrint::Printer::State
- Defined in:
- lib/report_print/printer.rb
Overview
:nodoc:
Instance Attribute Summary collapse
-
#after ⇒ Object
readonly
Returns the value of attribute after.
-
#indent ⇒ Object
readonly
Returns the value of attribute indent.
-
#inline_separator ⇒ Object
readonly
Returns the value of attribute inline_separator.
-
#mode ⇒ Object
readonly
Returns the value of attribute mode.
-
#next_inline_separator ⇒ Object
readonly
Returns the value of attribute next_inline_separator.
-
#separator ⇒ Object
readonly
Returns the value of attribute separator.
-
#start_of_block ⇒ Object
readonly
Returns the value of attribute start_of_block.
-
#start_of_line ⇒ Object
readonly
Returns the value of attribute start_of_line.
Instance Method Summary collapse
-
#inline? ⇒ Boolean
Ruby type checking can't really handle this type of dynamic programming very well yet, so we just skip type checking here as there is only the one short function.
Methods inherited from Data
Instance Attribute Details
#after ⇒ Object (readonly)
Returns the value of attribute after
8 9 10 |
# File 'lib/report_print/printer.rb', line 8 def after @after end |
#indent ⇒ Object (readonly)
Returns the value of attribute indent
8 9 10 |
# File 'lib/report_print/printer.rb', line 8 def indent @indent end |
#inline_separator ⇒ Object (readonly)
Returns the value of attribute inline_separator
8 9 10 |
# File 'lib/report_print/printer.rb', line 8 def inline_separator @inline_separator end |
#mode ⇒ Object (readonly)
Returns the value of attribute mode
8 9 10 |
# File 'lib/report_print/printer.rb', line 8 def mode @mode end |
#next_inline_separator ⇒ Object (readonly)
Returns the value of attribute next_inline_separator
8 9 10 |
# File 'lib/report_print/printer.rb', line 8 def next_inline_separator @next_inline_separator end |
#separator ⇒ Object (readonly)
Returns the value of attribute separator
8 9 10 |
# File 'lib/report_print/printer.rb', line 8 def separator @separator end |
#start_of_block ⇒ Object (readonly)
Returns the value of attribute start_of_block
8 9 10 |
# File 'lib/report_print/printer.rb', line 8 def start_of_block @start_of_block end |
#start_of_line ⇒ Object (readonly)
Returns the value of attribute start_of_line
8 9 10 |
# File 'lib/report_print/printer.rb', line 8 def start_of_line @start_of_line end |
Instance Method Details
#inline? ⇒ Boolean
Ruby type checking can't really handle this type of dynamic programming very well yet, so we just skip type checking here as there is only the one short function. steep:ignore:start
22 23 24 |
# File 'lib/report_print/printer.rb', line 22 def inline? mode == :inline end |